#!/usr/bin/env python

"""
General support for calendar data storage.

Copyright (C) 2016, 2017 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from imiptools.config import settings
from imiptools.stores.common import StoreInitialisationError
from imiptools.stores.manifest import stores

# Access functions.

def get_store(store_type=None, store_dir=None):

    """
    Return a store object for the given 'store_type' and 'store_dir', using
    configuration defaults where the parameters are given as None.
    """

    if store_dir or not store_type or store_type == settings["STORE_TYPE"]:
        return stores[store_type or settings["STORE_TYPE"]].Store(
            store_dir or settings["STORE_DIR"])
    else:
        raise StoreInitialisationError, "Store type cannot be changed arbitrarily."

def get_publisher(publishing_dir=None):

    """
    Return a publisher object for the given 'publishing_dir', using
    configuration defaults where the parameter is given as None.
    """

    return stores["file"].Publisher(
        publishing_dir or settings["PUBLISH_DIR"])

def get_journal(store_type=None, journal_dir=None):

    """
    Return a journal object for the given 'store_type' and 'journal_dir', using
    configuration defaults where the parameters are given as None.
    """

    if journal_dir or not store_type or store_type == settings["STORE_TYPE"]:
        return stores[store_type or settings["STORE_TYPE"]].Journal(
            journal_dir or settings["JOURNAL_DIR"])
    else:
        raise StoreInitialisationError, "Journal type cannot be changed arbitrarily."

# vim: tabstop=4 expandtab shiftwidth=4
